@@ -154,7 +154,7 @@ sub _run_resolver ($self) {
                             else {
                                 $data->[0]->set_status(200);
 
-                                $data->[0]->{result} = $status;
+                                $data->[0]->{data} = $status;
 
                                 $data->[1]->( $data->[0] );
                             }
