@@ -1,8 +1,8 @@
-package Pcore::Captcha v0.7.0;
+package Pcore::Captcha v0.8.0;
 
 use Pcore -dist, -class;
 
-with qw[Pcore::Util::Status::Role];
+with qw[Pcore::Util::Result::Status];
 
 has captcha => ( is => 'ro', isa => ScalarRef, required => 1 );
 
